@@ -141,6 +141,26 @@ fn statbar3() {
     drop(runlock);
 }
 
+// status bar test 4
+#[test]
+fn statbar4() {
+    let runlock = RUN.lock().unwrap();
+    let mut root = cursive::default();
+    root.set_theme(better_theme());
+    root.add_fullscreen_layer(
+        LinearLayout::vertical()
+            .child(
+                Dialog::text("Is there a message below this?")
+                    .button("Yes", |v| v.quit())
+                    .button("No", |_| panic!("StatusView test 4 failed!"))
+                    .title("Coof Testing")
+            )
+            .child(StatusView::new_with_label("Persistent label"))
+    );
+    root.run();
+    drop(runlock);
+}
+
 // select_view! macro test 1
 #[test]
 fn svmacro1() {
